#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# SPDX-License-Identifier: Apache-2.0
"""SDNC package."""
from .preload import NetworkPreload, VfModulePreload
